@@ -70,11 +70,13 @@
 ##'   interpreted as the sample size for the proposed study.
 ##'
 ##' @param pars Character vector identifying which parameters are learned from the proposed study.
-##' These should be columns of \code{inputs}.
+##' This is required for the moment matching and importance sampling methods,
+##' and these should be columns of \code{inputs}.   This is not required for the nonparametric
+##' regression methods.  
 ##' 
 ##' @param pars_datagen Character vector identifying which columns of \code{inputs} are
 ##'   the parameters required to generate data from the proposed study.
-##'   These should be columns of \code{inputs}.
+##'   These should be columns of \code{inputs}.   
 ##' 
 ##'   If \code{pars_datagen} is not supplied, then it is assumed to be the same as \code{pars}.
 ##'   Note that these can be different.  Even if the study data are generated by a particular parameter,
@@ -278,8 +280,6 @@ evsi <- function(outputs,
     check_inputs(inputs)
     check_ss(n)
     outputs <- check_outputs(outputs, inputs)
-    check_pars(pars, inputs, evppi=FALSE)
-    pars_datagen <- check_pars_datagen(pars, pars_datagen, inputs)
     if (is.null(method))
         method <- default_evsi_method()
 
@@ -290,6 +290,8 @@ evsi <- function(outputs,
     datagen_fn <- form_datagen_fn(study, datagen_fn, inputs, aux_pars)
     ## Could use any nonparametric regression method to regress on a summary statistic, in identical way to EVPPI estimation.
     
+    pars_datagen <- check_pars_datagen(pars, pars_datagen, inputs)
+    npreg_method <- default_npreg_method(pars)
     if (method %in% npreg_methods) { 
         res <- evsi_npreg(outputs=outputs, inputs=inputs, 
                    datagen_fn=datagen_fn, pars=pars_datagen, n=n, 
@@ -326,6 +328,7 @@ evsi <- function(outputs,
 evsi_npreg <- function(outputs, inputs, datagen_fn, pars, n, method=NULL, se=FALSE, B=500, verbose, check, aux_pars=NULL, ...){
     nn <- length(n)
     res <- vector(nn, mode="list")
+    validate_char(pars, "pars")
     for (i in seq_along(n)){
         Tdata <- generate_data(inputs, datagen_fn, n[i], pars, aux_pars)
         res[[i]] <- evppi_npreg(outputs=outputs, inputs=Tdata, 
@@ -455,7 +458,6 @@ form_analysis_args <- function(analysis_args, study, n){
 check_pars_datagen <- function(pars, pars_datagen, inputs){
   if (is.null(pars_datagen))
     pars_datagen <- pars
-  else 
-    check_pars(pars_datagen, inputs, evppi=FALSE)
+  check_pars(pars_datagen, inputs, evppi=FALSE)
   pars_datagen
 }
