@@ -97,10 +97,10 @@ expect_not_equal <- function(x, y) expect_true(!isTRUE(identical(x, y)))
 test_that("reference decision option",{
   expect_not_equal(
     evppi(multcomp_nb, multcomp_pars, pars=pi2, ref=3),
-    evppi(chemo_nb, chemo_pars, pars=pi2, ref=1)
+    evppi(multcomp_nb, multcomp_pars, pars=pi2, ref=1)
   )
   expect_not_equal(
-    evppi(multcomp_nb, multcomp_pars, pars=pi2, ref="Novel"),
-    evppi(chemo_nb, chemo_pars, pars=pi2, ref="SoC")
+    evppi(multcomp_nb, multcomp_pars, pars=pi2, ref="trt3"),
+    evppi(multcomp_nb, multcomp_pars, pars=pi2, ref="SoC")
   )
 })
